@@ -14,23 +14,21 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from networking_l2gw._i18n import _LI
-from networking_l2gw.tests.api import base_l2gw
-from networking_l2gw.tests.scenario import ovsdb_connections
-from networking_l2gw.tests.tempest import config
+import json
+import time
 
 from neutron.tests.api import base
 from neutron.tests.tempest import exceptions
 from neutron.tests.tempest import manager
-
 from oslo_log import log
 from tempest.lib.common import rest_client
 from tempest.lib.common.utils import data_utils
-from tempest.lib.common.utils import misc as misc_utils
+from tempest.lib.common.utils import test_utils
 from tempest.lib import exceptions as lib_exc
 
-import json
-import time
+from networking_l2gw.tests.api import base_l2gw
+from networking_l2gw.tests.scenario import ovsdb_connections
+from networking_l2gw.tests.tempest import config
 
 CONF = config.CONF
 LOG = log.getLogger(__name__)
@@ -121,8 +119,8 @@ class TestL2GatewayBasic(base.BaseAdminNetworkTest):
                 serverstatus = '/'.join((server_status, str(task_state)))
                 waitsec = (time.time() - start_time)
                 LOG.info(
-                    _LI('State transition %(oldstatus)s => %(serverstatus)s'
-                        'after %(waitsec)d second wait') %
+                    'State transition %(oldstatus)s => %(serverstatus)s'
+                    'after %(waitsec)d second wait' %
                     {'oldstatus': oldstatus, 'serverstatus': serverstatus,
                      'waitsec': waitsec}
                 )
@@ -144,7 +142,7 @@ class TestL2GatewayBasic(base.BaseAdminNetworkTest):
                             'timeout': timeout})
                 message += ' Current status: %s.' % server_status
                 message += ' Current task state: %s.' % task_state
-                caller = misc_utils.find_test_caller()
+                caller = test_utils.find_test_caller()
                 if caller:
                     message = '(%s) %s' % (caller, message)
                 raise exceptions.TimeoutException(message)
